:
# NAME:
#	dnsfuncs.sh - funcs used by cron jobs for DNS maint
#
# DESCRIPTION:
#	Changes the working directory to $DNSDIR which defaults to the
#	directory named in /etc/named.{boot,conf}
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: dnsfuncs.sh,v 1.8 2002/12/16 19:54:46 sjg Exp $
#
#	@(#) Copyright (c) 1994 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

_DNSFUNCS_SH=:

# pick up zap(), Which() etc
RC_D=${RC_D:-/etc/rc_d}
. $RC_D/funcs.sh

NDBOOT=${NDBOOT:-`Which -s /etc/named.conf`}	# bind-8
NDBOOT=${NDBOOT:-`Which -s /etc/named.boot`}

test -s ${NDBOOT:-/dev/null} || exit 0

case "$NDBOOT" in
*.conf)	exists /etc/rndc.* && BINDVERS=${BINDVERS:-9}
	BINDVERS=${BINDVERS:-8}
	;;
*)	BINDVERS=${BINDVERS:-4}
	;;
esac

case $BINDVERS in
9*)	RNDC=${RNDC:-`Which rndc /usr/pkg/sbin:$PATH`};;
esac

dnsDir() {
	awk '/^[ 	]*directory/ { print $2; exit 0 }' $NDBOOT | ${TR:-tr} -d '";'
}

# named always creates a pid file,
# but bind-8 removes it when it exits!
# so we need to be more rigid - for the sake of machines like gate
# which run multiple bind processes

dnsPidFile() {
	awk '/^[	]*pid-file/ { print $2; exit 0 }' ${1:-$NDBOOT} | ${TR:-tr} -d '";'
}

dnsPid() {
	pidf=${PID_FILE:-`dnsPidFile $1`}

	if test "$pidf"; then
		test -s $pidf && cat $pidf
	else
		for d in `IFS=: echo $PID_PATH` /var/run /etc
		do
			test -s $d/named.pid && { cat $d/named.pid; break; }
		done
	fi
}

DNSDIR=${DNSDIR:-`dnsDir`}
cd ${DNSDIR:-/dev/null} || exit 1
export DNSDIR NDBOOT 
